==> nats.c_3.9.2.orig.tar.gz: nats.c-3.9.2/doc/html/structjs_stream_config.js <==
var structjs_stream_config =
[
    [ "Name", "structjs_stream_config.html#a7fe3d5086f1c660a6999ae40ecd370e5", null ],
    [ "Description", "structjs_stream_config.html#a4f9f422d2e9e7389860291ab19bd7f10", null ],
    [ "Subjects", "structjs_stream_config.html#a0c5f3354073dbe72650e3db7f59a47af", null ],
    [ "SubjectsLen", "structjs_stream_config.html#ab2186aae798df6c222b3fa69e31597e1", null ],
    [ "Retention", "structjs_stream_config.html#a5ebc95b76afafa5e7a129953ba1bb3c7", null ],
    [ "MaxConsumers", "structjs_stream_config.html#a7338c82c8cbfcd5f4bfb7ad34b1d8395", null ],
    [ "MaxMsgs", "structjs_stream_config.html#a60a5184d1d97b056dbb31ac6a5b3d82d", null ],
    [ "MaxBytes", "structjs_stream_config.html#ad75e47d4293441bd5ddbc5eaf01e0451", null ],
    [ "MaxAge", "structjs_stream_config.html#aa538765ad97d343d60212ebd9894661e", null ],
    [ "MaxMsgsPerSubject", "structjs_stream_config.html#aa167c7547d13bf2a01510a375ad38340", null ],
    [ "MaxMsgSize", "structjs_stream_config.html#a93a2336a57b6bfb792d530fd13a90641", null ],
    [ "Discard", "structjs_stream_config.html#a0b44ea5251ef20bf5b5658bcfbea832d", null ],
    [ "Storage", "structjs_stream_config.html#a59c34091f336eafa77da2991c852c0d8", null ],
    [ "Replicas", "structjs_stream_config.html#adbf2c948cf8091b149603b918ef49ffc", null ],
    [ "NoAck", "structjs_stream_config.html#a8e358fbc569a1c6d49c704e6dbdf8609", null ],
    [ "Template", "structjs_stream_config.html#a50f866f0e73c4ff0a5f43b354a059fa9", null ],
    [ "Duplicates", "structjs_stream_config.html#a9e0ff10273d0182f885615b4f7d1cc20", null ],
    [ "Placement", "structjs_stream_config.html#acee6c66afc78d79c2f518eed89177efb", null ],
    [ "Mirror", "structjs_stream_config.html#acdba5b22e4e60fd81a54769a7d09bc51", null ],
    [ "Sources", "structjs_stream_config.html#a8f0ee08922e5b2108082b5b9e4a6284b", null ],
    [ "SourcesLen", "structjs_stream_config.html#a34960d6acc710c2f32b563f4bb7c9c0a", null ],
    [ "Sealed", "structjs_stream_config.html#aede3fd2ab13d230eda14c96f9997e1b7", null ],
    [ "DenyDelete", "structjs_stream_config.html#af2d42dd29b9a35257937aeeb53c9f287", null ],
    [ "DenyPurge", "structjs_stream_config.html#a575ffbaa85b0300032963296b090583a", null ],
    [ "AllowRollup", "structjs_stream_config.html#aba71cdb342181f52bb9f7ff5f770a1fa", null ],
    [ "RePublish", "structjs_stream_config.html#a95ab0061b6e935b129a4a9c133e6b11c", null ],
    [ "AllowDirect", "structjs_stream_config.html#a28630f6f07ca02553c5d5718d7c29721", null ],
    [ "MirrorDirect", "structjs_stream_config.html#a9d67ddcc7c54c345dd60ed5e59234f1e", null ],
    [ "DiscardNewPerSubject", "structjs_stream_config.html#a3fb7d5e1a09829fe742749da880afe4a", null ],
    [ "Metadata", "structjs_stream_config.html#a7aa4849b0f555c9de6b6da953929a565", null ],
    [ "Compression", "structjs_stream_config.html#a406554aaf1e16eed4abade52f7ca5e61", null ],
    [ "FirstSeq", "structjs_stream_config.html#a7ed5e8e5a8d367b25751b9708d0e395b", null ],
    [ "SubjectTransform", "structjs_stream_config.html#a0ce1d0a7c1f0576151f505724ae393d1", null ],
    [ "ConsumerLimits", "structjs_stream_config.html#a5ce51cb5a36febda30bb444a0f59c2d1", null ]
];

==> nats.c_3.11.0.orig.tar.gz: nats.c-3.11.0/doc/html/structjs_stream_config.js <==
var structjs_stream_config =
[
    [ "Name", "structjs_stream_config.html#a7fe3d5086f1c660a6999ae40ecd370e5", null ],
    [ "Description", "structjs_stream_config.html#a4f9f422d2e9e7389860291ab19bd7f10", null ],
    [ "Subjects", "structjs_stream_config.html#a0c5f3354073dbe72650e3db7f59a47af", null ],
    [ "SubjectsLen", "structjs_stream_config.html#ab2186aae798df6c222b3fa69e31597e1", null ],
    [ "Retention", "structjs_stream_config.html#a5ebc95b76afafa5e7a129953ba1bb3c7", null ],
    [ "MaxConsumers", "structjs_stream_config.html#a7338c82c8cbfcd5f4bfb7ad34b1d8395", null ],
    [ "MaxMsgs", "structjs_stream_config.html#a60a5184d1d97b056dbb31ac6a5b3d82d", null ],
    [ "MaxBytes", "structjs_stream_config.html#ad75e47d4293441bd5ddbc5eaf01e0451", null ],
    [ "MaxAge", "structjs_stream_config.html#aa538765ad97d343d60212ebd9894661e", null ],
    [ "MaxMsgsPerSubject", "structjs_stream_config.html#aa167c7547d13bf2a01510a375ad38340", null ],
    [ "MaxMsgSize", "structjs_stream_config.html#a93a2336a57b6bfb792d530fd13a90641", null ],
    [ "Discard", "structjs_stream_config.html#a0b44ea5251ef20bf5b5658bcfbea832d", null ],
    [ "Storage", "structjs_stream_config.html#a59c34091f336eafa77da2991c852c0d8", null ],
    [ "Replicas", "structjs_stream_config.html#adbf2c948cf8091b149603b918ef49ffc", null ],
    [ "NoAck", "structjs_stream_config.html#a8e358fbc569a1c6d49c704e6dbdf8609", null ],
    [ "Template", "structjs_stream_config.html#a50f866f0e73c4ff0a5f43b354a059fa9", null ],
    [ "Duplicates", "structjs_stream_config.html#a9e0ff10273d0182f885615b4f7d1cc20", null ],
    [ "Placement", "structjs_stream_config.html#acee6c66afc78d79c2f518eed89177efb", null ],
    [ "Mirror", "structjs_stream_config.html#acdba5b22e4e60fd81a54769a7d09bc51", null ],
    [ "Sources", "structjs_stream_config.html#a8f0ee08922e5b2108082b5b9e4a6284b", null ],
    [ "SourcesLen", "structjs_stream_config.html#a34960d6acc710c2f32b563f4bb7c9c0a", null ],
    [ "Sealed", "structjs_stream_config.html#aede3fd2ab13d230eda14c96f9997e1b7", null ],
    [ "DenyDelete", "structjs_stream_config.html#af2d42dd29b9a35257937aeeb53c9f287", null ],
    [ "DenyPurge", "structjs_stream_config.html#a575ffbaa85b0300032963296b090583a", null ],
    [ "AllowRollup", "structjs_stream_config.html#aba71cdb342181f52bb9f7ff5f770a1fa", null ],
    [ "RePublish", "structjs_stream_config.html#a95ab0061b6e935b129a4a9c133e6b11c", null ],
    [ "AllowDirect", "structjs_stream_config.html#a28630f6f07ca02553c5d5718d7c29721", null ],
    [ "MirrorDirect", "structjs_stream_config.html#a9d67ddcc7c54c345dd60ed5e59234f1e", null ],
    [ "DiscardNewPerSubject", "structjs_stream_config.html#a3fb7d5e1a09829fe742749da880afe4a", null ],
    [ "Metadata", "structjs_stream_config.html#a7aa4849b0f555c9de6b6da953929a565", null ],
    [ "Compression", "structjs_stream_config.html#a406554aaf1e16eed4abade52f7ca5e61", null ],
    [ "FirstSeq", "structjs_stream_config.html#a7ed5e8e5a8d367b25751b9708d0e395b", null ],
    [ "SubjectTransform", "structjs_stream_config.html#a0ce1d0a7c1f0576151f505724ae393d1", null ],
    [ "ConsumerLimits", "structjs_stream_config.html#a5ce51cb5a36febda30bb444a0f59c2d1", null ],
    [ "AllowMsgTTL", "structjs_stream_config.html#a54d080160cd8179c8c6f3982f0b11ab5", null ],
    [ "SubjectDeleteMarkerTTL", "structjs_stream_config.html#aa45bb2b4fb0e7ce71b77d9af91c0a6bd", null ]
];
